@@ -1,5 +1,5 @@
 use Log::Log4perl qw(:easy);
-use Log::Log4perl::CommandLine { layout => '%d %c %m%n' };
+use Log::Log4perl::CommandLine { layout => '%c %m%n' };
 
 DEBUG "debug message";
 INFO  "info  message";
